/* This file is automatically generated by gensymlist.sh. DO NOT EDIT! */
/*
 *  GRUB  --  GRand Unified Bootloader
 *  Copyright (C) 2002,2006,2007,2008,2009,2010  Free Software Foundation, Inc.
 *
 *  GRUB is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  GRUB is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with GRUB.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <../config.h>
#include <../../grub-2.06/include/grub/cache.h>
#include <../../grub-2.06/include/grub/command.h>
#include <../../grub-2.06/include/grub/device.h>
#include <../../grub-2.06/include/grub/disk.h>
#include <../../grub-2.06/include/grub/dl.h>
#include <../../grub-2.06/include/grub/efi/sb.h>
#include <../../grub-2.06/include/grub/env.h>
#include <../../grub-2.06/include/grub/env_private.h>
#include <../../grub-2.06/include/grub/err.h>
#include <../../grub-2.06/include/grub/file.h>
#include <../../grub-2.06/include/grub/fs.h>
#include <../../grub-2.06/include/grub/i18n.h>
#include <../../grub-2.06/include/grub/kernel.h>
#include <../../grub-2.06/include/grub/list.h>
#include <../../grub-2.06/include/grub/lockdown.h>
#include <../../grub-2.06/include/grub/misc.h>
#include <../../grub-2.06/include/grub/compiler-rt.h>
#include <../../grub-2.06/include/grub/mm.h>
#include <../../grub-2.06/include/grub/parser.h>
#include <../../grub-2.06/include/grub/partition.h>
#include <../../grub-2.06/include/grub/stack_protector.h>
#include <../../grub-2.06/include/grub/term.h>
#include <../../grub-2.06/include/grub/time.h>
#include <../../grub-2.06/include/grub/verify.h>
#include <../../grub-2.06/include/grub/mm_private.h>
#include <../../grub-2.06/include/grub/net.h>
#include <../../grub-2.06/include/grub/memory.h>
#include <../../grub-2.06/include/grub/efi/efi.h>
#include <../../grub-2.06/include/grub/efi/disk.h>
#include <../../grub-2.06/include/grub/acpi.h>

#define COMPILE_TIME_ASSERT(cond) switch (0) { case 1: case !(cond): ; }

#pragma GCC diagnostic ignored "-Wmissing-format-attribute"

void
grub_register_exported_symbols (void)
{
  struct symtab { const char *name; void *addr; int isfunc; };
  struct symtab *p;
  static struct symtab tab[] =
    {
      {"grub_acpi_find_fadt", grub_acpi_find_fadt, 1},
      {"grub_arch_sync_caches", grub_arch_sync_caches, 1},
      {"grub_byte_checksum", grub_byte_checksum, 1},
      {"grub_calloc", grub_calloc, 1},
      {"grub_command_list", (void *) &grub_command_list, 0},
      {"grub_current_context", (void *) &grub_current_context, 0},
      {"grub_debug_enabled", grub_debug_enabled, 1},
      {"grub_device_close", grub_device_close, 1},
      {"grub_device_iterate", grub_device_iterate, 1},
      {"grub_device_open", grub_device_open, 1},
      {"grub_disk_cache_table", (void *) &grub_disk_cache_table, 0},
      {"grub_disk_close", grub_disk_close, 1},
      {"grub_disk_dev_list", (void *) &grub_disk_dev_list, 0},
      {"grub_disk_dev_register", grub_disk_dev_register, 1},
      {"grub_disk_dev_unregister", grub_disk_dev_unregister, 1},
      {"grub_disk_firmware_fini", (void *) &grub_disk_firmware_fini, 0},
      {"grub_disk_firmware_is_tainted", (void *) &grub_disk_firmware_is_tainted, 0},
      {"grub_disk_native_sectors", grub_disk_native_sectors, 1},
      {"grub_disk_open", grub_disk_open, 1},
      {"grub_disk_read", grub_disk_read, 1},
      {"grub_disk_write_weak", (void *) &grub_disk_write_weak, 0},
      {"grub_divmod64", grub_divmod64, 1},
      {"grub_dl_head", (void *) &grub_dl_head, 0},
      {"grub_dl_load", grub_dl_load, 1},
      {"grub_dl_load_core_noinit", grub_dl_load_core_noinit, 1},
      {"grub_dl_ref", grub_dl_ref, 1},
      {"grub_dl_ref_count", grub_dl_ref_count, 1},
      {"grub_dl_unload", grub_dl_unload, 1},
      {"grub_dl_unref", grub_dl_unref, 1},
      {"grub_efi_allocate_any_pages", grub_efi_allocate_any_pages, 1},
      {"grub_efi_allocate_fixed", grub_efi_allocate_fixed, 1},
      {"grub_efi_allocate_pages_real", grub_efi_allocate_pages_real, 1},
      {"grub_efi_compare_device_paths", grub_efi_compare_device_paths, 1},
      {"grub_efi_duplicate_device_path", grub_efi_duplicate_device_path, 1},
      {"grub_efi_find_last_device_path", grub_efi_find_last_device_path, 1},
      {"grub_efi_find_mmap_size", grub_efi_find_mmap_size, 1},
      {"grub_efi_finish_boot_services", grub_efi_finish_boot_services, 1},
      {"grub_efi_free_pages", grub_efi_free_pages, 1},
      {"grub_efi_get_device_path", grub_efi_get_device_path, 1},
      {"grub_efi_get_filename", grub_efi_get_filename, 1},
      {"grub_efi_get_firmware_fdt", grub_efi_get_firmware_fdt, 1},
      {"grub_efi_get_loaded_image", grub_efi_get_loaded_image, 1},
      {"grub_efi_get_memory_map", grub_efi_get_memory_map, 1},
      {"grub_efi_get_ram_base", grub_efi_get_ram_base, 1},
      {"grub_efi_get_secureboot", grub_efi_get_secureboot, 1},
      {"grub_efi_get_variable", grub_efi_get_variable, 1},
      {"grub_efi_get_variable_with_attributes", grub_efi_get_variable_with_attributes, 1},
      {"grub_efi_image_handle", (void *) &grub_efi_image_handle, 0},
      {"grub_efi_is_finished", (void *) &grub_efi_is_finished, 0},
      {"grub_efi_locate_handle", grub_efi_locate_handle, 1},
      {"grub_efi_locate_protocol", grub_efi_locate_protocol, 1},
      {"grub_efi_net_config", (void *) &grub_efi_net_config, 0},
      {"grub_efi_open_protocol", grub_efi_open_protocol, 1},
      {"grub_efi_print_device_path", grub_efi_print_device_path, 1},
      {"grub_efi_set_text_mode", grub_efi_set_text_mode, 1},
      {"grub_efi_set_variable", grub_efi_set_variable, 1},
      {"grub_efi_set_virtual_address_map", grub_efi_set_virtual_address_map, 1},
      {"grub_efi_stall", grub_efi_stall, 1},
      {"grub_efi_system_table", (void *) &grub_efi_system_table, 0},
      {"grub_efidisk_get_device_handle", grub_efidisk_get_device_handle, 1},
      {"grub_efidisk_get_device_name", grub_efidisk_get_device_name, 1},
      {"grub_env_export", grub_env_export, 1},
      {"grub_env_get", grub_env_get, 1},
      {"grub_env_set", grub_env_set, 1},
      {"grub_env_unset", grub_env_unset, 1},
      {"grub_env_update_get_sorted", grub_env_update_get_sorted, 1},
      {"grub_err_printed_errors", (void *) &grub_err_printed_errors, 0},
      {"grub_errmsg", (void *) &grub_errmsg, 0},
      {"grub_errno", (void *) &grub_errno, 0},
      {"grub_error", grub_error, 1},
      {"grub_error_pop", grub_error_pop, 1},
      {"grub_error_push", grub_error_push, 1},
      {"grub_exit", grub_exit, 1},
      {"grub_fatal", grub_fatal, 1},
      {"grub_file_close", grub_file_close, 1},
      {"grub_file_filters", (void *) &grub_file_filters, 0},
      {"grub_file_get_device_name", grub_file_get_device_name, 1},
      {"grub_file_open", grub_file_open, 1},
      {"grub_file_progress_hook", (void *) &grub_file_progress_hook, 0},
      {"grub_file_read", grub_file_read, 1},
      {"grub_file_seek", grub_file_seek, 1},
      {"grub_file_verifiers", (void *) &grub_file_verifiers, 0},
      {"grub_free", grub_free, 1},
      {"grub_fs_autoload_hook", (void *) &grub_fs_autoload_hook, 0},
      {"grub_fs_list", (void *) &grub_fs_list, 0},
      {"grub_fs_probe", grub_fs_probe, 1},
      {"grub_get_time_ms", grub_get_time_ms, 1},
      {"grub_getkey", grub_getkey, 1},
      {"grub_getkey_noblock", grub_getkey_noblock, 1},
      {"grub_getkeystatus", grub_getkeystatus, 1},
      {"grub_gettext", (void *) &grub_gettext, 0},
      {"grub_is_lockdown", grub_is_lockdown, 1},
      {"grub_isspace", grub_isspace, 1},
      {"grub_key_is_interrupt", grub_key_is_interrupt, 1},
      {"grub_list_push", grub_list_push, 1},
      {"grub_list_remove", grub_list_remove, 1},
      {"grub_lockdown", grub_lockdown, 1},
      {"grub_machine_acpi_get_rsdpv1", grub_machine_acpi_get_rsdpv1, 1},
      {"grub_machine_acpi_get_rsdpv2", grub_machine_acpi_get_rsdpv2, 1},
      {"grub_machine_fini", grub_machine_fini, 1},
      {"grub_malloc", grub_malloc, 1},
      {"grub_memalign", grub_memalign, 1},
      {"grub_memcmp", grub_memcmp, 1},
      {"grub_memmove", grub_memmove, 1},
      {"grub_memset", grub_memset, 1},
      {"grub_millisleep", grub_millisleep, 1},
      {"grub_mm_base", (void *) &grub_mm_base, 0},
      {"grub_modbase", (void *) &grub_modbase, 0},
      {"grub_named_list_find", grub_named_list_find, 1},
      {"grub_net_open", (void *) &grub_net_open, 0},
      {"grub_net_poll_cards_idle", (void *) &grub_net_poll_cards_idle, 0},
      {"grub_parser_cmdline_state", grub_parser_cmdline_state, 1},
      {"grub_parser_split_cmdline", grub_parser_split_cmdline, 1},
      {"grub_partition_get_name", grub_partition_get_name, 1},
      {"grub_partition_iterate", grub_partition_iterate, 1},
      {"grub_partition_map_list", (void *) &grub_partition_map_list, 0},
      {"grub_partition_probe", grub_partition_probe, 1},
      {"grub_print_error", grub_print_error, 1},
      {"grub_printf", grub_printf, 1},
      {"grub_printf_", grub_printf_, 1},
      {"grub_printf_fmt_check", grub_printf_fmt_check, 1},
      {"grub_puts_", grub_puts_, 1},
      {"grub_real_dprintf", grub_real_dprintf, 1},
      {"grub_realloc", grub_realloc, 1},
      {"grub_reboot", grub_reboot, 1},
      {"grub_refresh", grub_refresh, 1},
      {"grub_register_command_lockdown", grub_register_command_lockdown, 1},
      {"grub_register_command_prio", grub_register_command_prio, 1},
      {"grub_register_variable_hook", grub_register_variable_hook, 1},
      {"grub_snprintf", grub_snprintf, 1},
      {"grub_strchr", grub_strchr, 1},
      {"grub_strcmp", grub_strcmp, 1},
      {"grub_strcpy", grub_strcpy, 1},
      {"grub_strdup", grub_strdup, 1},
      {"grub_strlen", grub_strlen, 1},
      {"grub_strncmp", grub_strncmp, 1},
      {"grub_strndup", grub_strndup, 1},
      {"grub_strrchr", grub_strrchr, 1},
      {"grub_strtoul", grub_strtoul, 1},
      {"grub_strtoull", grub_strtoull, 1},
      {"grub_strword", grub_strword, 1},
      {"grub_term_highlight_color", (void *) &grub_term_highlight_color, 0},
      {"grub_term_inputs", (void *) &grub_term_inputs, 0},
      {"grub_term_inputs_disabled", (void *) &grub_term_inputs_disabled, 0},
      {"grub_term_normal_color", (void *) &grub_term_normal_color, 0},
      {"grub_term_outputs", (void *) &grub_term_outputs, 0},
      {"grub_term_outputs_disabled", (void *) &grub_term_outputs_disabled, 0},
      {"grub_term_poll_usb", (void *) &grub_term_poll_usb, 0},
      {"grub_unregister_command", grub_unregister_command, 1},
      {"grub_verify_string", grub_verify_string, 1},
      {"grub_vprintf", grub_vprintf, 1},
      {"grub_vsnprintf", grub_vsnprintf, 1},
      {"grub_xasprintf", grub_xasprintf, 1},
      {"grub_xputs", (void *) &grub_xputs, 0},
      {"grub_xvasprintf", grub_xvasprintf, 1},
      {"grub_zalloc", grub_zalloc, 1},
      {"memcmp", memcmp, 1},
      {"memcpy", memcpy, 1},
      {"memmove", memmove, 1},
      {"memset", memset, 1},
      {0, 0, 0}
    };

  COMPILE_TIME_ASSERT (sizeof (tab) > sizeof (tab[0]));
  for (p = tab; p->name; p++)
    grub_dl_register_symbol (p->name, p->addr, p->isfunc, 0);
}
